@@ -1,8 +1,8 @@
 use crate::api::{publisher_client::PublisherClient, subscriber_client::SubscriberClient};
 use crate::certs::get_pem;
+use crate::error::Error;
 use crate::subscription::Subscription;
 use crate::topic::Topic;
-use anyhow::Result;
 use google_auth::TokenManager;
 use tonic::transport::{Certificate, Channel, ClientTlsConfig};
 use tonic::{IntoRequest, Request};
@@ -22,7 +22,7 @@ impl Client {
         "https://www.googleapis.com/auth/cloud-platform",
         "https://www.googleapis.com/auth/pubsub",
     ];
-    pub async fn new(project_id: &str) -> Result<Self> {
+    pub async fn new(project_id: &str) -> Result<Self, Error> {
         let pem = get_pem();
         let tls_config = ClientTlsConfig::new()
             .ca_certificate(Certificate::from_pem(&pem))
@@ -44,11 +44,11 @@ impl Client {
     pub(crate) async fn insert_authz_token<T: IntoRequest<T>>(
         &mut self,
         request: T,
-    ) -> Result<Request<T>> {
+    ) -> Result<Request<T>, Error> {
         let mut request = request.into_request();
         let token = self.token_manager.token().await?;
         let metadata = request.metadata_mut();
-        metadata.insert("authorization", token.parse().unwrap());
+        metadata.insert("authorization", token.parse()?);
         Ok(request)
     }
     pub fn subscription(&self, subscription_name: &str) -> Subscription {
