@@ -1,9 +1,9 @@
 use crate::api::{PullRequest, ReceivedMessage};
 use crate::client::Client;
+use crate::error::Error;
 use crate::message::Message;
-use anyhow::Result;
-use log::debug;
 use std::collections::VecDeque;
+use tracing::error;
 
 pub struct Subscription {
     pub(crate) name: String,
@@ -19,7 +19,7 @@ impl Subscription {
             buffer: VecDeque::new(),
         }
     }
-    async fn pull(&mut self, max_messages: i32) -> Result<Vec<ReceivedMessage>> {
+    async fn pull(&mut self, max_messages: i32) -> Result<Vec<ReceivedMessage>, Error> {
         let mut pr = PullRequest::default();
         pr.subscription = self.name.clone();
         pr.max_messages = max_messages;
@@ -30,8 +30,14 @@ impl Subscription {
     pub async fn receive(&mut self) -> Option<Message> {
         loop {
             if let Some(handle) = self.buffer.pop_front() {
-                let pubsub_message = handle.message.unwrap();
-                let timestamp = pubsub_message.publish_time.unwrap();
+                let pubsub_message = match handle.message {
+                    Some(m) => m,
+                    None => continue,
+                };
+                let timestamp = match pubsub_message.publish_time {
+                    Some(t) => t,
+                    None => continue,
+                };
                 let message = Message {
                     client: self.client.clone(),
                     subscription_name: self.name.clone(),
@@ -44,20 +50,17 @@ impl Subscription {
                         timestamp.nanos as u32,
                     ),
                 };
-                debug!("got message and break");
                 break Some(message);
             } else {
                 match self.pull(50).await {
                     Ok(messages) => {
                         if messages.is_empty() {
-                            debug!("got empty message and break");
                             break None;
                         }
-                        debug!("pulled new message(s) and extend to buffer");
                         self.buffer.extend(messages)
                     }
                     Err(err) => {
-                        debug!("pull message failed{}", err);
+                        error!("pull message failed{}", err);
                         continue;
                     }
                 };
